Stan Math Library: stan/math/prim/arr/meta/container_view.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
container_view.hpp File Reference
`#include <stan/math/prim/scal/meta/container_view.hpp>`
`#include <vector>`

Go to the source code of this file.

## Classes
class | stan::math::container_view< std::vector< T1 >, T2 >
| Template specialization for scalar view of array y with scalar type T2 with proper indexing inferred from input vector x of scalar type T1. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.